@@ -3,12 +3,12 @@ use std::{env, path::PathBuf};
 use clap_generate::generators::{Bash, Elvish, Fish, Zsh};
 use mit_build_tools::{completion, manpage};
 
-#[path = "src/cli.rs"]
-mod cli;
+#[path = "src/cli/app.rs"]
+mod app;
 
 fn main() {
     let out_dir = PathBuf::from(env::var_os("OUT_DIR").unwrap());
-    let app = cli::app();
+    let app = app::app();
 
     completion::generate::<Elvish>(&app, &out_dir.join("elvish_completion"));
     completion::generate::<Fish>(&app, &out_dir.join("fish_completion"));
